@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -24,21 +24,30 @@
 #error "Only <parole.h> can be included directly."
 #endif
 
-#ifndef __PAROLE_PL_PARSER_H
-#define __PAROLE_PL_PARSER_H
+#ifndef SRC_MISC_PAROLE_PL_PARSER_H_
+#define SRC_MISC_PAROLE_PL_PARSER_H_
 
 #include <glib.h>
 
 G_BEGIN_DECLS
 
-typedef enum
-{
+/**
+ * ParolePlFormat:
+ * @PAROLE_PL_FORMAT_UNKNOWN: Unknown format
+ * @PAROLE_PL_FORMAT_M3U: M3U format
+ * @PAROLE_PL_FORMAT_PLS: PLS format
+ * @PAROLE_PL_FORMAT_ASX: ASX format
+ * @PAROLE_PL_FORMAT_XSPF: XSPF format
+ *
+ * Parole Playlist Formats.
+ *
+ **/
+typedef enum {
     PAROLE_PL_FORMAT_UNKNOWN,
     PAROLE_PL_FORMAT_M3U,
     PAROLE_PL_FORMAT_PLS,
     PAROLE_PL_FORMAT_ASX,
     PAROLE_PL_FORMAT_XSPF
-    
 } ParolePlFormat;
 
 ParolePlFormat      parole_pl_parser_guess_format_from_extension    (const gchar *filename);
@@ -57,4 +66,4 @@ gboolean            parole_pl_parser_save_from_files                (GSList *fil
 
 G_END_DECLS
 
-#endif /* __PAROLE_PL_PARSER_H */
+#endif /* SRC_MISC_PAROLE_PL_PARSER_H_ */
