@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2014 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2014 Simon Steinbeiß <ochosi@xfce.org>
+ * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -33,20 +33,18 @@
 #endif
 #include <libxfce4util/libxfce4util.h>
 
-#include "parole-about.h"
+#include "src/parole-about.h"
 
 
 /**
  * parole_about:
- * @parent : the parent application window.
+ * @parent : the parent application window
  *
  * Display the About dialog for Parole.
  **/
-void parole_about (GtkWindow *parent)
-{
+void parole_about(GtkWindow *parent) {
     /* List of authors */
-    static const gchar *authors[] = 
-    {
+    static const gchar *authors[] = {
         "Ali Abdallah <aliov@xfce.org>",
         "Sean Davis <bluesabre@xfce.org>",
         "Simon Steinbeiss <simon@xfce.org>",
@@ -54,18 +52,18 @@ void parole_about (GtkWindow *parent)
     };
 
     /* List of documentation writers */
-    static const gchar *documenters[] =
-    {
+    static const gchar *documenters[] = {
         "Ali Abdallah <aliov@xfce.org>",
+        "Sean Davis <bluesabre@xfce.org>",
         NULL,
     };
-    
+
     /* Copyright information */
-    static const gchar *copyrights = 
+    static const gchar *copyrights =
     "Copyright \302\251 2009-2011 Ali Abdallah\n"
-    "Copyright \302\251 2012-2014 Sean Davis, Simon Steinbeiss";
-    
-    gtk_show_about_dialog  (parent,
+    "Copyright \302\251 2012-2017 Sean Davis, Simon Steinbeiss";
+
+    gtk_show_about_dialog(parent,
         "authors", authors,
         "comments", _("Parole Media Player"),
         "documenters", documenters,
@@ -75,7 +73,7 @@ void parole_about (GtkWindow *parent)
         "program-name", PACKAGE_NAME,
         "translator-credits", _("translator-credits"),
         "version", PACKAGE_VERSION,
-        "website", "http://docs.xfce.org/apps/parole/start",
+        "website", "https://docs.xfce.org/apps/parole/start",
         "website-label", _("Visit Parole website"),
         NULL);
 }
