@@ -157,9 +157,6 @@ gboolean    parole_media_list_query_tooltip(GtkWidget *widget,
  * End of GtkBuilder callbacks
  */
 
-#define PAROLE_MEDIA_LIST_GET_PRIVATE(o) \
-(G_TYPE_INSTANCE_GET_PRIVATE((o), PAROLE_TYPE_MEDIA_LIST, ParoleMediaListPrivate))
-
 struct ParoleMediaListPrivate {
     DBusGConnection     *bus;
     ParoleConf          *conf;
@@ -198,7 +195,7 @@ enum {
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE(ParoleMediaList, parole_media_list, GTK_TYPE_BOX)
+G_DEFINE_TYPE_WITH_PRIVATE(ParoleMediaList, parole_media_list, GTK_TYPE_BOX)
 
 static void
 parole_media_list_set_widget_sensitive(ParoleMediaList *list, gboolean sensitive) {
@@ -599,7 +596,7 @@ parole_media_list_get_first_selected_row(ParoleMediaList *list) {
         }
     }
 
-    g_list_foreach(path_list, (GFunc)gtk_tree_path_free, NULL);
+    g_list_foreach(path_list, (GFunc) (void (*)(void)) gtk_tree_path_free, NULL);
     g_list_free(path_list);
 
     return row;
@@ -924,7 +921,7 @@ parole_media_list_remove_clicked_cb(GtkButton *button, ParoleMediaList *list) {
         gtk_tree_path_free(prev);
     }
 
-    g_list_foreach(path_list, (GFunc)gtk_tree_path_free, NULL);
+    g_list_foreach(path_list, (GFunc) (void (*)(void)) gtk_tree_path_free, NULL);
     g_list_free(path_list);
 
     len = g_list_length(row_list);
@@ -941,7 +938,7 @@ parole_media_list_remove_clicked_cb(GtkButton *button, ParoleMediaList *list) {
         }
     }
 
-    g_list_foreach(row_list, (GFunc)gtk_tree_row_reference_free, NULL);
+    g_list_foreach(row_list, (GFunc) (void (*)(void)) gtk_tree_row_reference_free, NULL);
     g_list_free(row_list);
 
     /*
@@ -999,7 +996,7 @@ parole_media_list_move_up_clicked_cb(GtkButton *button, ParoleMediaList *list) {
         }
     }
 
-    g_list_foreach(path_list, (GFunc)gtk_tree_path_free, NULL);
+    g_list_foreach(path_list, (GFunc) (void (*)(void)) gtk_tree_path_free, NULL);
     g_list_free(path_list);
 }
 
@@ -1043,7 +1040,7 @@ parole_media_list_move_down_clicked_cb(GtkButton *button, ParoleMediaList *list)
         }
     }
 
-    g_list_foreach(path_list, (GFunc)gtk_tree_path_free, NULL);
+    g_list_foreach(path_list, (GFunc) (void (*)(void)) gtk_tree_path_free, NULL);
     g_list_free(path_list);
 }
 
@@ -1366,8 +1363,6 @@ parole_media_list_class_init(ParoleMediaListClass *klass) {
                       g_cclosure_marshal_VOID__STRING,
                       G_TYPE_NONE, 1, G_TYPE_STRING);
 
-    g_type_class_add_private (klass, sizeof (ParoleMediaListPrivate));
-
     parole_media_list_dbus_class_init(klass);
 }
 
@@ -1498,7 +1493,7 @@ parole_media_list_init(ParoleMediaList *list) {
     GtkWidget  *box;
 
     media_list = list;
-    list->priv = PAROLE_MEDIA_LIST_GET_PRIVATE(list);
+    list->priv = parole_media_list_get_instance_private(list);
 
     list->priv->bus = parole_g_session_bus_get();
 
@@ -1957,7 +1952,7 @@ void parole_media_list_save_list(ParoleMediaList *list) {
         fileslist = parole_media_list_get_files(list);
         if ( g_slist_length(fileslist) > 0 ) {
             parole_pl_parser_save_from_files(fileslist, history, PAROLE_PL_FORMAT_M3U);
-            g_slist_foreach(fileslist, (GFunc)g_object_unref, NULL);
+            g_slist_foreach(fileslist, (GFunc) (void (*)(void)) g_object_unref, NULL);
         } else {
             // If the playlist is empty, delete the list.
             if (remove(history) != 0)
