@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -20,11 +20,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __PAROLE_MEDIA_LIST_H
-#define __PAROLE_MEDIA_LIST_H
+#ifndef SRC_PAROLE_MEDIALIST_H_
+#define SRC_PAROLE_MEDIALIST_H_
 
 #include <gtk/gtk.h>
-#include <src/misc/parole-file.h>
+
+#include "src/misc/parole-file.h"
 
 G_BEGIN_DECLS
 
@@ -32,8 +33,7 @@ G_BEGIN_DECLS
 #define PAROLE_MEDIA_LIST(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), PAROLE_TYPE_MEDIA_LIST, ParoleMediaList))
 #define PAROLE_IS_MEDIA_LIST(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), PAROLE_TYPE_MEDIA_LIST))
 
-enum
-{
+enum {
     STATE_COL,
     NAME_COL,
     LENGTH_COL,
@@ -41,31 +41,25 @@ enum
     COL_NUMBERS
 };
 
-enum
-{
+enum {
     PAROLE_MEDIA_STATE_NONE,
     PAROLE_MEDIA_STATE_PAUSED,
     PAROLE_MEDIA_STATE_PLAYING
 };
 
-enum
-{
+enum {
     PAROLE_MEDIA_LIST_PLAYLIST_VIEW_STANDARD,
     PAROLE_MEDIA_LIST_PLAYLIST_VIEW_DISC
 };
 
 typedef struct ParoleMediaListPrivate ParoleMediaListPrivate;
 
-typedef struct
-{
+typedef struct {
     GtkBox                      parent;
-
     ParoleMediaListPrivate     *priv;
-
 } ParoleMediaList;
 
-typedef struct
-{
+typedef struct {
     GtkBoxClass     parent_class;
 
     void            (*media_activated)              (ParoleMediaList *list,
@@ -88,7 +82,6 @@ typedef struct
 
     void            (*dvd_chapter_count)            (ParoleMediaList *list,
                                                      gint chapter_count);
-
 } ParoleMediaListClass;
 
 GType               parole_media_list_get_type      (void) G_GNUC_CONST;
@@ -202,4 +195,4 @@ void parole_media_list_add_dvd (ParoleMediaList *list, gchar *dvd_name);
 
 G_END_DECLS
 
-#endif /* __PAROLE_MEDIA_LIST_H */
+#endif /* SRC_PAROLE_MEDIALIST_H_ */
